<?php
/**
* @version $Id: script.BSBanner.php $
* @version		1.4.2 23/08/2019
* @package		BSBanner
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2019 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die();

class Pkg_BSBannerInstallerScript
{
	protected $minimumPHPVersion = '5.3.1';
	protected $minimumJoomlaVersion = '3.4.0';
	protected $currentMyJspaceVersion = '';
	protected $componentName = 'BS Banner pack';

	/**
	 * Joomla! pre-flight event. This runs before Joomla! installs or updates the package. This is our last chance to
	 * tell Joomla! if it should abort the installation.
	 *
	 * @param   string                     $type    Installation type (install, update, discover_install)
	 * @param   \JInstallerAdapterPackage  $parent  Parent object
	 *
	 * @return  boolean  True to let the installation proceed, false to halt the installation
	 */
	public function preflight($type, $parent)
	{
		// Get the Package version
		$file = $parent->getParent()->getPath('source').'/pkg_BSBanner.xml';
		libxml_use_internal_errors(true);
		if (file_exists($file)) {
			$xml = simplexml_load_file($file);

			if (isset($xml) && isset($xml->version))
				$this->currentMyJspaceVersion = (string)$xml->version;
		}

		if (version_compare(JVERSION, $this->minimumJoomlaVersion, 'lt')) { // Check Joomla! version for component compatibility
			JFactory::getApplication()->enqueueMessage('You need at least Joomla! '.$this->minimumJoomlaVersion.' to install this '.$this->componentName.' version', 'error');
			return false;
		}

		if (version_compare(PHP_VERSION, $this->minimumPHPVersion, 'lt')) { // Check PHP version for component compatibility
			JFactory::getApplication()->enqueueMessage('You need at least PHP '.$this->minimumPHPVersion.' to install this '.$this->componentName.' version', 'error');
			return false;
		}
		
		return true;
	}

	/**
	 * Runs after install, update or discover_update. In other words, it executes after Joomla! has finished installing
	 * or updating your component. This is the last chance you've got to perform any additional installations, clean-up,
	 * database updates and similar housekeeping functions.
	 *
	 * @param   string                       $type   install, uninstall, update or discover_update
	 * @param   \JInstallerAdapterComponent  $parent Parent object
	 */
	public function postflight($type, $parent)
	{
		if ($type == 'install' || $type == 'update') {
			$msg = '
			<div style="text-align: left;">
				<div>BS Banner '.$this->currentMyJspaceVersion.' pack</div>
				<div class="button2-left">
					<div class="blank">
						<a class="modal-button btn btn-primary" href="index.php?option=com_bsbanner&view=bsbanner">Configuration</a>
					</div>
				</div>
			</div>
			';
			JFactory::getApplication()->enqueueMessage($msg, 'notice');
		}

		return true;
	}

	/**
	 * Tuns on installation (but not on upgrade). This happens in install and discover_install installation routes.
	 *
	 * @param   \JInstallerAdapterPackage  $parent  Parent object
	 *
	 * @return  bool
	 */
	public function install($parent)
	{
		return true;
	}

	/**
	 * Runs on uninstallation
	 *
	 * @param   \JInstallerAdapterPackage  $parent  Parent object
	 *
	 * @return  bool
	 */
	public function uninstall($parent)
	{
		return true;
	}

}
