<?php
/**
* @version $Id: script.bsbanner.php $
* @version		1.4.2 23/08/2019
* @package		com_bsbanner
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2012 - 2019 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/
 
defined('_JEXEC') or die;

class com_bsbannerInstallerScript
{
	protected $minimumPHPVersion = '5.3.1';
	protected $minimumJoomlaVersion = '3.4.0';
	protected $componentName = 'BS Banner';
	protected $component = 'com_bsbanner';

	// Method for pre-install
	public function preflight($type, $parent)
	{
		if (version_compare(JVERSION, $this->minimumJoomlaVersion, 'lt')) { // Check Joomla! version for component compatibility
			JFactory::getApplication()->enqueueMessage('You need at least Joomla! '.$this->minimumJoomlaVersion.' to install this '.$this->componentName.' version', 'error');
			return false;
		}

		if (version_compare(PHP_VERSION, $this->minimumPHPVersion, 'lt')) { // Check PHP version for component compatibility
			JFactory::getApplication()->enqueueMessage('You need at least PHP '.$this->minimumPHPVersion.' to install this '.$this->componentName.' version', 'error');
			return false;
		}

		return true;
	}

	public function postflight($type, $parent) {

		if ($type == 'install' || $type == 'update') {

			// Installation & migrations
			$fichier_param = JPATH_ROOT.'/components/com_bsbanner/models';
			if (!@file_exists($fichier_param.'/#ref-image.conf2.php'))
				@copy($fichier_param.'/#ref-image.conf2_model.php', $fichier_param.'/#ref-image.conf2.php');

			$asset	= JTable::getInstance('asset');

			if (!$asset->loadByName('com_bsbanner')) {
				$root = JTable::getInstance('asset');
				$root->loadByName('root.1');
				$asset->name = 'com_bsbanner';
				$asset->title = 'com_bsbanner';
				$asset->setLocation($root->id, 'last-child');
			};

			// Component first Install
			if ($asset->rules == '' || $asset->rules == '{}') { // No Rules => Store the default ACL rules into the database
				$asset->rules = '{"core.manage":{"6":1,"7":1},"user.bsbanner":{"6":1,"7":1,"2":1},"user.data":{"6":1,"7":1,"2":1},"user.doc":{"6":1,"7":1,"2":1},"user.edit":{"6":1,"7":1,"2":1},"user.supp":{"6":1,"7":1,"2":1},"core.admin":{"7":1},"core.options":{"7":1}}';

				if (!$asset->check() || !$asset->store()) { 
					$this->setError($asset->getError());
					return false;
				}
			}

			// User Actions Log
			if (version_compare(JVERSION, '3.9.0', 'ge')) {
				$db	= JFactory::getDBO();

				// Add the extension to the table (#__action_logs_extensions) so that it will appear in the configuration of User Actions Log
				$query = 'SELECT COUNT(*) FROM '.$db->quoteName('#__action_logs_extensions').' WHERE '.$db->quoteName('extension').' = '.$db->quote($this->component);
				$db->setQuery($query);
				$count = $db->loadResult();	
				if (!isset($count))
					return false;

				if ($count == 0) {
					$db->setQuery('INSERT into #__action_logs_extensions (extension) VALUES ('.$db->quote($this->component).')');
					try { // If it fails, it will throw a RuntimeException
						$db->execute();
					} catch (RuntimeException $e) {
						\Joomla\CMS\Factory::getApplication()->enqueueMessage($e->getMessage());
						return false;
					}
				}

				// Add configuration for media upload
				$query = 'SELECT COUNT(*) FROM '.$db->quoteName('#__action_log_config').' WHERE '.$db->quoteName('type_alias').' = '.$db->quote($this->component.'.media');
				$db->setQuery($query);
				$count = $db->loadResult();	
				if (!isset($count))
					return false;

				if ($count == 0) {
					$logConf = new stdClass();
					$logConf->id = 0;
					$logConf->type_title = 'media';
					$logConf->type_alias = $this->component.'.media';
					$logConf->id_holder = 'id';
					$logConf->title_holder = 'name';
					$logConf->table_name = '';
					$logConf->text_prefix = 'COM_BSBANNER_TRANSACTION';

					try {
						// If it fails, it will throw a RuntimeException
						// Insert the object into the table.
						\Joomla\CMS\Factory::getDbo()->insertObject('#__action_log_config', $logConf);
					} catch (RuntimeException $e) {
						\Joomla\CMS\Factory::getApplication()->enqueueMessage($e->getMessage());
						return false;
					}
				}
			}
		}

		if ($type == 'udpate') {
			// Delete the old site update url (http://)
			$db	= JFactory::getDBO();
			$query = 'SELECT '.$db->quoteName('update_site_id').' FROM '.$db->quoteName('#__update_sites').' WHERE '.$db->quoteName('location').' LIKE '.$db->quote('http://%bsbanner-update.xml');
			$db->setQuery($query, null, 1);
			$update_site_id = $db->loadResult();

			if ($update_site_id > 0) { // Previous install with 'http' to be deleted
				$db	= JFactory::getDBO();
				$query = 'DELETE FROM '.$db->quoteName('#__update_sites').' WHERE '.$db->quoteName('update_site_id').' = '.$db->quote(intval($update_site_id));
				$db->setQuery($query);
				$db->execute();

				$db	= JFactory::getDBO();
				$query = 'DELETE FROM '.$db->quoteName('#__update_sites_extensions').' WHERE '.$db->quoteName('update_site_id').' = '.$db->quote(intval($update_site_id));
				$db->setQuery($query);
				$db->execute();
			}

			// Old files unused (< BS MyJSpace 1.4.0)
			@unlink(JPATH_ADMINISTRATOR.'/components/com_bsbanner/_bsbanner.xml');
		}

		return true;
	}
}

?>
