<?php
/**
* @version $Id: controller.php $ 
* @version		1.4.2 23/08/2019
* @package		bsbanner
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2008 - 2019 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die;

class BsbannerController extends JControllerLegacy
{
	function display($cachable = false, $urlparams = false)
	{
		$jinput = JFactory::getApplication()->input;
		$acces_ok = true;
		$user = JFactory::getuser();
		$get_view = $jinput->get('view', '', 'STRING');

		// J! ACL
		// View
		if ($get_view != '' && !JFactory::getUser()->authorise('user.'.$get_view, 'com_bsbanner'))
			$acces_ok = false;

		if ($acces_ok == false && !isset($user->username)) { // Redirect to login page
			$uri = JURI::getInstance();
			$return = $uri->toString();

			$url = JRoute::_('index.php?option=com_users&view=login&return='.base64_encode($return), false); // To redirect to the originally call page

			$this->setRedirect($url);
			return;
		} else if ($acces_ok == false && isset($user->username)) { // Not allowed
			$this->setRedirect('index.php', JText::_('BSBNR_NOT_ALLOWED'), 'error');
		}

		parent::display();
	}

	// Créer la 'vignette'
	function cree()
	{
		JSession::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$jinput = JFactory::getApplication()->input;

		$model = $this->getModel();
		$user = JFactory::getuser();
		$id_tmp = $user->username;
		$app = JFactory::getApplication();	
		$params = $app->getParams();
		$signature = 0;
		$retour = 0;

		if (isset($id_tmp) && isset($_POST)) {
			$retour = $model->cree_image_fichier($user, $_POST);
			if ($retour != 0 && $params->get('kunena_add_signature', 0) > 0) { // Kunena signature ?
				$fichier = JPATH_COMPONENT_SITE.'/plugin/plug_kunena/kunena.php';
				if (@file_exists($fichier)) {
					require_once $fichier;

					$instance = $jinput->get('instance', 1, 'INT');
					if ($params->get('kunena_add_signature', 0) == 1)
						$kunena_add_signature_choice = $params->get('kunena_add_signature_choice', 2);
					else
						$kunena_add_signature_choice = $jinput->get('kunena_add_signature_choice', $params->get('kunena_add_signature_choice', 2), 'INT');
					$signature = BS_kunena::update_signature($user, $instance, $kunena_add_signature_choice);
				}
			}
		}

		if ($retour != 0) {
			$app->enqueueMessage(JText::_('BSBNR_CTRL_NEW_BAN'));

			$user = JFactory::getUser();

			// Add event
			$app = JFactory::getApplication();
			$object_file = new JObject();
			$object_file->name = $user->username.'-'.$retour;
			$object_file->id = $object_file->name;
			$app->triggerEvent('onContentAfterSave', array('com_bsbanner.media', $object_file, true));

			if ($signature)
				$app->enqueueMessage(JText::_('BSBNR_KUNENA_SIGNATURE_UPDATED'));

			$this->setRedirect(JRoute::_('index.php?option=com_bsbanner&view=bsbanner&instance='.$retour, false));
		} else
			$this->setRedirect(JRoute::_('index.php?option=com_bsbanner&view=edit', false), JText::_('BSBNR_CTRL_NEW_BAN_KO'), 'error');
	}
	 
	// Supprimer la vignette
	function supp()
	{
		JSession::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$jinput = JFactory::getApplication()->input;

		$model = $this->getModel();
		$user = JFactory::getuser();
		$id_tmp = $user->username;
		$inst = $jinput->get('instance', 0, 'INT');
		$retour = false;

		if (isset($id_tmp) && $inst != null) {
			$retour = $model->supp_image_fichier($id_tmp, $inst);
			
			$user = JFactory::getUser();

			// Add event
			$app = JFactory::getApplication();
			$object_file = new JObject();
			$object_file->name = $user->username.'-'.$inst;
			$object_file->id = $object_file->name;
			$app->triggerEvent('onContentAfterDelete', array('com_bsbanner.media', $object_file));			
		}

		if ($retour == true)
			$this->setRedirect(JRoute::_('index.php?option=com_bsbanner&view=bsbanner&instance='.$inst, false), JText::sprintf('BSBNR_CTRL_SUP_BAN', $inst), 'message');
		else
			$this->setRedirect(JRoute::_('index.php?option=com_bsbanner&view=bsbanner&instance='.$inst, false), JText::sprintf('BSBNR_CTRL_SUP_BAN_KO', $inst), 'error');
	}

	// Supprimer les données (de l'instance)
	function suppdata()
	{
		JSession::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$jinput = JFactory::getApplication()->input;

		$user = JFactory::getuser();
		$pparams = JComponentHelper::getParams('com_bsbanner');
		$plugin = $pparams->get('plugin', 'data_default');
		$inst = $jinput->get('instance', 0, 'INT');
		$retour = false;

		$plugin_file = JPATH_COMPONENT_SITE.'/plugin/plug_data_default/data_default.php';
		if (@file_exists($plugin_file))
			require_once $plugin_file;
		$plugin_file = JPATH_COMPONENT_SITE.'/plugin/plug_'.$plugin.'/'.$plugin.'.php';
		if (@file_exists($plugin_file)) {
			require_once $plugin_file;

			// Nom plugin
			$nom_class = 'BS_'.$plugin;
			$mon_obj = new $nom_class;

			// Efface les donnees (de l'instance de l'utilisateur)
			$retour = $mon_obj->delete_data($user->id, $inst);
		}

		if ($retour == true)
			$this->setRedirect(JRoute::_('index.php?option=com_bsbanner&view=bsbanner&instance='.$inst, false), JText::sprintf('BSBNR_CTRL_SUP_BAN_DATA', $inst), 'message');
		else
			$this->setRedirect(JRoute::_('index.php?option=com_bsbanner&view=bsbanner&instance='.$inst, false), JText::sprintf('BSBNR_CTRL_SUP_BAN_DATA_KO', $inst), 'error');
	}

	// Exporte toutes les données de l'utilisateur
	function export()
	{
		JSession::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$user = JFactory::getuser();
		$pparams = JComponentHelper::getParams('com_bsbanner');
		$plugin = $pparams->get('plugin', 'data_default');
		$data_user_export = $pparams->get('data_user_export', 1);
		$data_user_impexp_sep = $pparams->get('data_user_impexp_sep', ';');

		if ($data_user_export == 0)
			return;

		$basename = $_SERVER['HTTP_HOST'].'-'.date('YmdHis').'.csv'; // AJOUTER DATE YYYMMDDHHMMSS
//		$filesize = @filesize($filename);

//		while (@ob_end_clean());
//		@clearstatcache();

		// MIME headers
		header('MIME-Version: 1.0');
		header('Content-Disposition: attachment; filename='.$basename);
		header('Content-Transfer-Encoding: binary');
		header('Accept-Ranges: bytes');

		// Notify of filesize, if this info is available
//		if ($filesize > 0) header('Content-Length: '.@filesize($filename));
		// Disable cache
		header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
		header("Expires: 0");
		header('Pragma: no-cache');
		flush();

		$plugin_file = JPATH_COMPONENT_SITE.'/plugin/plug_data_default/data_default.php';
		if (@file_exists($plugin_file))
			require_once $plugin_file;
		$plugin_file = JPATH_COMPONENT_SITE.'/plugin/plug_'.$plugin.'/'.$plugin.'.php';
		if (@file_exists($plugin_file)) {
			require_once $plugin_file;
			
			// Nom plugin
			$nom_class = 'BS_'.$plugin;
			$mon_obj = new $nom_class;
			
			// Toutes les donnees de l'utilisateur
			$madata = $mon_obj->load_data_format($user->id, 0, 1, 0, null, null);
			echo $mon_obj->data_list_txt($madata, $data_user_impexp_sep, 0, JText::_('BSBNR_DATE_CALENDAR'));
			$madata = null; // 'Free' memory 
		}

		exit(0);
	}
	
	// Importe des données de l'utilisateur
	function import()
	{
		JSession::checkToken('post') or jexit(JText::_('JINVALID_TOKEN'));

		$jinput = JFactory::getApplication()->input;

		$user = JFactory::getuser();
		$pparams = JComponentHelper::getParams('com_bsbanner');
		$plugin = $pparams->get('plugin', 'data_default');
		$data_user_impexp_sep = $pparams->get('data_user_impexp_sep', ';');
		$instance = $jinput->get('instance', 0, 'INT');
		$data_user_import = $pparams->get('data_user_import', 1);
		$archive_data_user_nb = $pparams->get('archive_data_user_nb', 200);
		$archive_data_user_days = $pparams->get('archive_data_user_days', 200);
		$retour = 0;

		if ($data_user_import == 0 || $instance == 0)
			return;

		if (isset($_FILES['userfile']['tmp_name']))
			$fichier = $_FILES['userfile']['tmp_name'];
		else
			$fichier = null;

		$plugin_file = JPATH_COMPONENT_SITE.'/plugin/plug_data_default/data_default.php';
		if (@file_exists($plugin_file))
			require_once $plugin_file;
		$plugin_file = JPATH_COMPONENT_SITE.'/plugin/plug_'.$plugin.'/'.$plugin.'.php';
		if (@file_exists($plugin_file) && isset($fichier)) {
			require_once $plugin_file;
			require_once JPATH_COMPONENT_SITE.'/models/bsbanner.php';

			// Nom plugin
			$nom_class = 'BS_'.$plugin;
			$mon_obj = new $nom_class;

			$madata = $mon_obj->data_import($fichier, $data_user_impexp_sep, $archive_data_user_nb);
			$madata = BsbannerModelBsbanner::valid_data($madata, JText::_('BSBNR_DATE_CALENDAR'), 1); // Test format and transform formats
			$retour = $mon_obj->save_data_format($madata, $user->id, $instance);
			$madata = null; // Free memory as soon as possible
			@unlink($fichier); // Par secu, non indispensable
			$mon_obj->delete_exta_data($user->id, $archive_data_user_days, $archive_data_user_nb);
		}			

		if ($retour == 1)
			$this->setRedirect(JRoute::_('index.php?option=com_bsbanner&view=data', false), JText::_('BSBNR_MSG_DATA_IMPORT_OK'), 'message');
		else
			$this->setRedirect(JRoute::_('index.php?option=com_bsbanner&view=data', false), JText::_('BSBNR_MSG_DATA_IMPORT_KO'), 'error');
	}
}
?>
